#!/usr/bin/env node

import parseArguments from 'argument-parser';
import { getPatch, Product, verifyProductName } from 'ssn';

const { args, fail } = parseArguments({
  product: { short: 'p', description: 'Name of the product you want to install', verify: verifyProductName, message: (value) => `"${value}" is not a valid product name.` },
  from: { short: 'f', description: 'Number of the from release, must be an integer in the range [-1, 999]', verify: (str) => (str.match(/^(-1|0|[1-9][0-9]{0,2})$/) !== null) },
  to: { short: 't', description: 'Number of the to release, must be an integer in the range [0, 999]', verify: (str) => (str.match(/^(0|[1-9][0-9]{0,2})$/) !== null) },
}, (origArgs) => ((origArgs.length === 3) ? ['--product', origArgs[0], '--from', origArgs[1], '--to', origArgs[2]] : undefined));

//TODO: set directory with existing patch data
//TODO: set target directory where patch should be installed
//TODO: set temp directory where patch files should be stored.
//TODO: set from=any so it detects current version automatically (based on .version files)
//TODO: set to=manifest/current to install whatever is the current version in manifest/on CDN

(async () => {
  try {
    await getPatch({
     product: args.product as Product,
      from: Number(args.from),
      to: Number(args.to),
      sourceDirectory: process.cwd(),
      targetDirectory: process.cwd(),
    });
  } catch (error) {
    fail(error);
  }
})();
